# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/unused_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/inventory/v1/unused_resource.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"b\n\x17UnusedResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x84\x02\n\x13UnusedResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1a\n\x12unused_resource_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_list\x18\x06 \x03(\t\x12\x13\n\x0bregion_list\x18\x07 \x03(\t\x12\x13\n\x0b\x61nalyzed_at\x18\x08 \x01(\t\x12\x15\n\rservice_group\x18\t \x03(\t\x12\x15\n\rresource_type\x18\n \x01(\t\"\xab\x04\n\x12UnusedResourceInfo\x12\x1a\n\x12unused_resource_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\x12\x13\n\x0b\x61nalyzed_at\x18\x08 \x01(\t\x12\x15\n\rresource_type\x18\t \x01(\t\x12\x0e\n\x06reason\x18\n \x01(\t\x12\r\n\x05state\x18\x0b \x01(\t\x12\x13\n\x0bsaving_cost\x18\x0c \x01(\x01\x12\x19\n\x11\x61ttached_instance\x18\r \x01(\t\x12\x0e\n\x06region\x18\x0e \x01(\t\x12\x15\n\rresource_name\x18\x0f \x01(\t\x12\x13\n\x0bresource_id\x18\x10 \x01(\t\x12\x15\n\rservice_group\x18\x11 \x01(\t\x12\x0c\n\x04type\x18\x12 \x01(\t\x12%\n\x04\x64\x61ta\x18\x13 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0c\x63loud_svc_id\x18\x14 \x01(\t\x12\x1b\n\x13resource_setting_id\x18\x15 \x01(\t\x12%\n\x04tags\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\tcost_data\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\"j\n\x13UnusedResourcesInfo\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.spaceone.api.inventory.v1.UnusedResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xcd\x02\n\x0eUnusedResource\x12\xb7\x01\n\x04list\x12..spaceone.api.inventory.v1.UnusedResourceQuery\x1a..spaceone.api.inventory.v1.UnusedResourcesInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/inventory/v1/unused-resourcesZ\'\"%/inventory/v1/unused-resources/search\x12\x80\x01\n\x04stat\x12\x32.spaceone.api.inventory.v1.UnusedResourceStatQuery\x1a\x17.google.protobuf.Struct\"+\x82\xd3\xe4\x93\x02%\"#/inventory/v1/unused-resources/statb\x06proto3')



_UNUSEDRESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['UnusedResourceStatQuery']
_UNUSEDRESOURCEQUERY = DESCRIPTOR.message_types_by_name['UnusedResourceQuery']
_UNUSEDRESOURCEINFO = DESCRIPTOR.message_types_by_name['UnusedResourceInfo']
_UNUSEDRESOURCESINFO = DESCRIPTOR.message_types_by_name['UnusedResourcesInfo']
UnusedResourceStatQuery = _reflection.GeneratedProtocolMessageType('UnusedResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDRESOURCESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedResourceStatQuery)
  })
_sym_db.RegisterMessage(UnusedResourceStatQuery)

UnusedResourceQuery = _reflection.GeneratedProtocolMessageType('UnusedResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDRESOURCEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.unused_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedResourceQuery)
  })
_sym_db.RegisterMessage(UnusedResourceQuery)

UnusedResourceInfo = _reflection.GeneratedProtocolMessageType('UnusedResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDRESOURCEINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedResourceInfo)
  })
_sym_db.RegisterMessage(UnusedResourceInfo)

UnusedResourcesInfo = _reflection.GeneratedProtocolMessageType('UnusedResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _UNUSEDRESOURCESINFO,
  '__module__' : 'spaceone.api.inventory.v1.unused_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UnusedResourcesInfo)
  })
_sym_db.RegisterMessage(UnusedResourcesInfo)

_UNUSEDRESOURCE = DESCRIPTOR.services_by_name['UnusedResource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UNUSEDRESOURCE.methods_by_name['list']._options = None
  _UNUSEDRESOURCE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002I\022\036/inventory/v1/unused-resourcesZ\'\"%/inventory/v1/unused-resources/search'
  _UNUSEDRESOURCE.methods_by_name['stat']._options = None
  _UNUSEDRESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002%\"#/inventory/v1/unused-resources/stat'
  _UNUSEDRESOURCESTATQUERY._serialized_start=201
  _UNUSEDRESOURCESTATQUERY._serialized_end=299
  _UNUSEDRESOURCEQUERY._serialized_start=302
  _UNUSEDRESOURCEQUERY._serialized_end=562
  _UNUSEDRESOURCEINFO._serialized_start=565
  _UNUSEDRESOURCEINFO._serialized_end=1120
  _UNUSEDRESOURCESINFO._serialized_start=1122
  _UNUSEDRESOURCESINFO._serialized_end=1228
  _UNUSEDRESOURCE._serialized_start=1231
  _UNUSEDRESOURCE._serialized_end=1564
# @@protoc_insertion_point(module_scope)
